==> inspect-api-0.0.61-20250811.034517-2-sources.jar: com/tll/inspect/rpc/TravelAuditRpcService.java <==
package com.tll.inspect.rpc;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.tll.inspect.Application;
import com.tll.inspect.rpc.dto.travel.AuditSubmitFailRpcDTO;
import com.tll.inspect.rpc.dto.travel.TravelDeleteSubmitRpcDTO;
import com.tll.inspect.rpc.dto.travel.TravelProcessReceiveRpcDTO;
import com.tll.inspect.rpc.dto.travel.TravelUpdateSubmitRpcDTO;
import com.tll.inspect.rpc.vo.TravelChangeSubmitRpcVO;
import com.tll.inspect.rpc.vo.travel.TravelProcessReceiveRpcVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

@FeignClient(name = Application.NAME, path = TravelAuditRpcService.URI)
@Validated
public interface TravelAuditRpcService {

    String URI = Application.URI_PREFIX + "/travel/audit";

    @PostMapping("/updateSubmit")
    @ApiOperation("行程编辑提交审核")
    ApiResult<TravelChangeSubmitRpcVO> updateSubmit(@RequestBody TravelUpdateSubmitRpcDTO dto);

    @PostMapping("/deleteSubmit")
    @ApiOperation("行程删除提交审核")
    ApiResult<TravelChangeSubmitRpcVO> deleteSubmit(@RequestBody TravelDeleteSubmitRpcDTO dto);

    @PostMapping("/processAuditReceive")
    @ApiOperation("接收审核流结果")
    ApiResult<TravelProcessReceiveRpcVO> processAuditReceive(@RequestBody TravelProcessReceiveRpcDTO rpcDTO);

    @PostMapping("/processAuditSubmitFail")
    @ApiOperation("接收处理审核流提交异常")
    ApiResult<Void> processAuditSubmitFail(@RequestBody AuditSubmitFailRpcDTO rpcDTO);

}

==> inspect-api-1.0.14-20251022.023204-1-sources.jar: com/tll/inspect/rpc/TravelAuditRpcService.java <==
package com.tll.inspect.rpc;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.tll.inspect.Application;
import com.tll.inspect.rpc.dto.travel.AuditSubmitFailRpcDTO;
import com.tll.inspect.rpc.dto.travel.TravelDeleteSubmitRpcDTO;
import com.tll.inspect.rpc.dto.travel.TravelProcessReceiveRpcDTO;
import com.tll.inspect.rpc.dto.travel.TravelUpdateSubmitRpcDTO;
import com.tll.inspect.rpc.vo.TravelChangeSubmitRpcVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

@FeignClient(name = Application.NAME, path = TravelAuditRpcService.URI)
@Validated
public interface TravelAuditRpcService {

    String URI = Application.URI_PREFIX + "/travel/audit";

    @PostMapping("/updateSubmit")
    @ApiOperation("行程编辑提交审核")
    ApiResult<TravelChangeSubmitRpcVO> updateSubmit(@RequestBody TravelUpdateSubmitRpcDTO dto);

    @PostMapping("/deleteSubmit")
    @ApiOperation("行程删除提交审核")
    ApiResult<TravelChangeSubmitRpcVO> deleteSubmit(@RequestBody TravelDeleteSubmitRpcDTO dto);

    @PostMapping("/processAuditReceive")
    @ApiOperation("接收审核流结果")
    ApiResult<TravelChangeSubmitRpcVO> processAuditReceive(@RequestBody TravelProcessReceiveRpcDTO rpcDTO);

    @PostMapping("/processAuditSubmitFail")
    @ApiOperation("接收处理审核流提交异常")
    ApiResult<Void> processAuditSubmitFail(@RequestBody AuditSubmitFailRpcDTO rpcDTO);

}
